@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use Error::Pure qw(err);
-use List::MoreUtils qw(any);
+use List::Util qw(any);
 use Readonly;
 
 # Constants.
@@ -13,7 +13,7 @@ Readonly::Array our @EXPORT_OK => qw(set_params set_params_pub set_split_params
 	split_params);
 
 # Version.
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 # Set parameters to user values.
 sub set_params {
@@ -110,39 +110,68 @@ Class::Utils - Class utilities.
 
 =head1 SUBROUTINES
 
-=over 8
+=head2 C<set_params>
 
-=item C<set_params($self, @params)>
+ set_params($self, @params);
 
- Sets object parameters to user values.
- If setted key doesn't exist in $self object, turn fatal error.
- $self - Object or hash reference.
- @params - Key, value pairs.
+Sets object parameters to user values.
+If set key doesn't exist in C<$self> object, turn fatal error.
 
-=item C<set_params_pub($self, @params)>
+$self - Object or hash reference.
+@params - Key, value pairs.
 
- Sets object parameters to user values. Only public arguments.
- Private arguments are defined by '_' character on begin of key and will be
- skip.
- If setted public key doesn't exist in $self object, turn fatal error.
- $self - Object or hash reference.
- @params - Key, value pairs.
+=head2 C<set_params_pub>
 
-=item C<set_split_params($self, @params)>
+ set_params_pub($self, @params);
 
- Set object params and other returns.
- $self - Object or hash reference.
- @params - Key, value pairs.
- Returns array with other parameters.
+Sets object parameters to user values. Only public arguments.
+Private arguments are defined by '_' character on begin of key and will be
+skip.
+If set public key doesn't exist in C<$self> object, turn fatal error.
 
-=item C<split_params($object_keys_ar, @params)>
+=over
 
- Split params to list of object params and other params.
- Returns array with two values. First is reference to array with object
- parameters. Second in reference to array with other parameters.
+=item C<$self>
+
+Object or hash reference.
+
+=item C<@params>
+
+Key, value pairs.
 
 =back
 
+Returns undef.
+
+=head2 C<set_split_params>
+
+ my @other_params = set_split_params($self, @params);
+
+Set object params and other returns.
+
+=over
+
+=item C<$self>
+
+Object or hash reference.
+
+=item C<@params>
+
+Key, value pairs.
+
+=back
+
+Returns list of parameters.
+
+=head2 C<split_params>
+
+ my ($object_params_ar, $other_params_ar) = split_params($object_keys_ar, @params);
+
+Split params to list of object params and other params.
+
+Returns array with two values. First is reference to array with object
+parameters. Second in reference to array with other parameters.
+
 =head1 ERRORS
 
  set_params():
@@ -153,6 +182,8 @@ Class::Utils - Class utilities.
 
 =head1 EXAMPLE1
 
+=for comment filename=set_params_ok.pl
+
  use strict;
  use warnings;
 
@@ -174,6 +205,8 @@ Class::Utils - Class utilities.
 
 =head1 EXAMPLE2
 
+=for comment filename=set_params_fail.pl
+
  use strict;
  use warnings;
 
@@ -189,6 +222,8 @@ Class::Utils - Class utilities.
 
 =head1 EXAMPLE3
 
+=for comment filename=set_params_pub.pl
+
  use strict;
  use warnings;
 
@@ -213,6 +248,8 @@ Class::Utils - Class utilities.
 
 =head1 EXAMPLE4
 
+=for comment filename=set_split_params.pl
+
  use strict;
  use warnings;
 
@@ -240,6 +277,8 @@ Class::Utils - Class utilities.
 
 =head1 EXAMPLE5
 
+=for comment filename=split_params.pl
+
  use strict;
  use warnings;
 
@@ -269,7 +308,7 @@ Class::Utils - Class utilities.
 
 L<Error::Pure>,
 L<Exporter>,
-L<List::MoreUtils>,
+L<List::Util>,
 L<Readonly>.
 
 =head1 REPOSITORY
@@ -284,12 +323,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2011-2022
+© 2011-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
